# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Migration Hub"
prefix = "mgh"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateCreatedArtifact = Action("AssociateCreatedArtifact")
AssociateDiscoveredResource = Action("AssociateDiscoveredResource")
CreateHomeRegionControl = Action("CreateHomeRegionControl")
CreateProgressUpdateStream = Action("CreateProgressUpdateStream")
DeleteProgressUpdateStream = Action("DeleteProgressUpdateStream")
DescribeApplicationState = Action("DescribeApplicationState")
DescribeHomeRegionControls = Action("DescribeHomeRegionControls")
DescribeMigrationTask = Action("DescribeMigrationTask")
DisassociateCreatedArtifact = Action("DisassociateCreatedArtifact")
DisassociateDiscoveredResource = Action("DisassociateDiscoveredResource")
GetHomeRegion = Action("GetHomeRegion")
ImportMigrationTask = Action("ImportMigrationTask")
ListApplicationStates = Action("ListApplicationStates")
ListCreatedArtifacts = Action("ListCreatedArtifacts")
ListDiscoveredResources = Action("ListDiscoveredResources")
ListMigrationTasks = Action("ListMigrationTasks")
ListProgressUpdateStreams = Action("ListProgressUpdateStreams")
NotifyApplicationState = Action("NotifyApplicationState")
NotifyMigrationTaskState = Action("NotifyMigrationTaskState")
PutResourceAttributes = Action("PutResourceAttributes")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Elastic Load Balancing"
prefix = "elasticloadbalancing"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddListenerCertificates = Action("AddListenerCertificates")
AddTags = Action("AddTags")
ApplySecurityGroupsToLoadBalancer = Action("ApplySecurityGroupsToLoadBalancer")
AttachLoadBalancerToSubnets = Action("AttachLoadBalancerToSubnets")
ConfigureHealthCheck = Action("ConfigureHealthCheck")
CreateAppCookieStickinessPolicy = Action("CreateAppCookieStickinessPolicy")
CreateLBCookieStickinessPolicy = Action("CreateLBCookieStickinessPolicy")
CreateListener = Action("CreateListener")
CreateLoadBalancer = Action("CreateLoadBalancer")
CreateLoadBalancerListeners = Action("CreateLoadBalancerListeners")
CreateLoadBalancerPolicy = Action("CreateLoadBalancerPolicy")
CreateRule = Action("CreateRule")
CreateTargetGroup = Action("CreateTargetGroup")
DeleteListener = Action("DeleteListener")
DeleteLoadBalancer = Action("DeleteLoadBalancer")
DeleteLoadBalancerListeners = Action("DeleteLoadBalancerListeners")
DeleteLoadBalancerPolicy = Action("DeleteLoadBalancerPolicy")
DeleteRule = Action("DeleteRule")
DeleteTargetGroup = Action("DeleteTargetGroup")
DeregisterInstancesFromLoadBalancer = Action("DeregisterInstancesFromLoadBalancer")
DeregisterTargets = Action("DeregisterTargets")
DescribeAccountLimits = Action("DescribeAccountLimits")
DescribeInstanceHealth = Action("DescribeInstanceHealth")
DescribeListenerCertificates = Action("DescribeListenerCertificates")
DescribeListeners = Action("DescribeListeners")
DescribeLoadBalancerAttributes = Action("DescribeLoadBalancerAttributes")
DescribeLoadBalancerPolicies = Action("DescribeLoadBalancerPolicies")
DescribeLoadBalancerPolicyTypes = Action("DescribeLoadBalancerPolicyTypes")
DescribeLoadBalancers = Action("DescribeLoadBalancers")
DescribeRules = Action("DescribeRules")
DescribeSSLPolicies = Action("DescribeSSLPolicies")
DescribeTags = Action("DescribeTags")
DescribeTargetGroupAttributes = Action("DescribeTargetGroupAttributes")
DescribeTargetGroups = Action("DescribeTargetGroups")
DescribeTargetHealth = Action("DescribeTargetHealth")
DetachLoadBalancerFromSubnets = Action("DetachLoadBalancerFromSubnets")
DisableAvailabilityZonesForLoadBalancer = Action(
    "DisableAvailabilityZonesForLoadBalancer"
)
EnableAvailabilityZonesForLoadBalancer = Action(
    "EnableAvailabilityZonesForLoadBalancer"
)
ModifyListener = Action("ModifyListener")
ModifyLoadBalancerAttributes = Action("ModifyLoadBalancerAttributes")
ModifyRule = Action("ModifyRule")
ModifyTargetGroup = Action("ModifyTargetGroup")
ModifyTargetGroupAttributes = Action("ModifyTargetGroupAttributes")
RegisterInstancesWithLoadBalancer = Action("RegisterInstancesWithLoadBalancer")
RegisterTargets = Action("RegisterTargets")
RemoveListenerCertificates = Action("RemoveListenerCertificates")
RemoveTags = Action("RemoveTags")
SetIpAddressType = Action("SetIpAddressType")
SetLoadBalancerListenerSSLCertificate = Action("SetLoadBalancerListenerSSLCertificate")
SetLoadBalancerPoliciesForBackendServer = Action(
    "SetLoadBalancerPoliciesForBackendServer"
)
SetLoadBalancerPoliciesOfListener = Action("SetLoadBalancerPoliciesOfListener")
SetRulePriorities = Action("SetRulePriorities")
SetSecurityGroups = Action("SetSecurityGroups")
SetSubnets = Action("SetSubnets")
SetWebAcl = Action("SetWebAcl")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Marketplace"
prefix = "aws-marketplace"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptAgreementApprovalRequest = Action("AcceptAgreementApprovalRequest")
AssociateProductsWithPrivateMarketplace = Action(
    "AssociateProductsWithPrivateMarketplace"
)
BatchMeterUsage = Action("BatchMeterUsage")
CancelAgreementRequest = Action("CancelAgreementRequest")
CancelChangeSet = Action("CancelChangeSet")
CompleteTask = Action("CompleteTask")
CreatePrivateMarketplace = Action("CreatePrivateMarketplace")
CreatePrivateMarketplaceProfile = Action("CreatePrivateMarketplaceProfile")
CreatePrivateMarketplaceRequests = Action("CreatePrivateMarketplaceRequests")
DescribeAgreement = Action("DescribeAgreement")
DescribeBuilds = Action("DescribeBuilds")
DescribeChangeSet = Action("DescribeChangeSet")
DescribeEntity = Action("DescribeEntity")
DescribePrivateMarketplaceProducts = Action("DescribePrivateMarketplaceProducts")
DescribePrivateMarketplaceProfile = Action("DescribePrivateMarketplaceProfile")
DescribePrivateMarketplaceRequests = Action("DescribePrivateMarketplaceRequests")
DescribePrivateMarketplaceSettings = Action("DescribePrivateMarketplaceSettings")
DescribePrivateMarketplaceStatus = Action("DescribePrivateMarketplaceStatus")
DescribeProcurementSystemConfiguration = Action(
    "DescribeProcurementSystemConfiguration"
)
DescribeTask = Action("DescribeTask")
DisassociateProductsFromPrivateMarketplace = Action(
    "DisassociateProductsFromPrivateMarketplace"
)
GetAgreementApprovalRequest = Action("GetAgreementApprovalRequest")
GetAgreementRequest = Action("GetAgreementRequest")
GetAgreementTerms = Action("GetAgreementTerms")
GetEntitlements = Action("GetEntitlements")
ListAgreementApprovalRequests = Action("ListAgreementApprovalRequests")
ListAgreementRequests = Action("ListAgreementRequests")
ListBuilds = Action("ListBuilds")
ListChangeSets = Action("ListChangeSets")
ListEntities = Action("ListEntities")
ListPrivateMarketplaceProducts = Action("ListPrivateMarketplaceProducts")
ListPrivateMarketplaceRequests = Action("ListPrivateMarketplaceRequests")
ListTasks = Action("ListTasks")
MeterUsage = Action("MeterUsage")
PutProcurementSystemConfiguration = Action("PutProcurementSystemConfiguration")
RegisterUsage = Action("RegisterUsage")
RejectAgreementApprovalRequest = Action("RejectAgreementApprovalRequest")
ResolveCustomer = Action("ResolveCustomer")
SearchAgreements = Action("SearchAgreements")
StartBuild = Action("StartBuild")
StartChangeSet = Action("StartChangeSet")
StartPrivateMarketplace = Action("StartPrivateMarketplace")
StopPrivateMarketplace = Action("StopPrivateMarketplace")
Subscribe = Action("Subscribe")
Unsubscribe = Action("Unsubscribe")
UpdateAgreementApprovalRequest = Action("UpdateAgreementApprovalRequest")
UpdatePrivateMarketplaceProfile = Action("UpdatePrivateMarketplaceProfile")
UpdatePrivateMarketplaceSettings = Action("UpdatePrivateMarketplaceSettings")
UpdateTask = Action("UpdateTask")
ViewSubscriptions = Action("ViewSubscriptions")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Panorama"
prefix = "panorama"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApp = Action("CreateApp")
CreateAppDeployment = Action("CreateAppDeployment")
CreateAppVersion = Action("CreateAppVersion")
CreateDataSource = Action("CreateDataSource")
CreateDeploymentConfiguration = Action("CreateDeploymentConfiguration")
CreateDevice = Action("CreateDevice")
CreateDeviceUpdate = Action("CreateDeviceUpdate")
CreateInputs = Action("CreateInputs")
CreateModel = Action("CreateModel")
CreateStreams = Action("CreateStreams")
DeleteApp = Action("DeleteApp")
DeleteAppVersion = Action("DeleteAppVersion")
DeleteDataSource = Action("DeleteDataSource")
DeleteDevice = Action("DeleteDevice")
DeleteModel = Action("DeleteModel")
DescribeApp = Action("DescribeApp")
DescribeAppDeployment = Action("DescribeAppDeployment")
DescribeAppVersion = Action("DescribeAppVersion")
DescribeDataSource = Action("DescribeDataSource")
DescribeDevice = Action("DescribeDevice")
DescribeDeviceUpdate = Action("DescribeDeviceUpdate")
DescribeModel = Action("DescribeModel")
DescribeSoftware = Action("DescribeSoftware")
GetDeploymentConfiguration = Action("GetDeploymentConfiguration")
GetInputs = Action("GetInputs")
GetStreams = Action("GetStreams")
GetWebSocketURL = Action("GetWebSocketURL")
ListAppDeploymentOperations = Action("ListAppDeploymentOperations")
ListAppVersions = Action("ListAppVersions")
ListApps = Action("ListApps")
ListDataSources = Action("ListDataSources")
ListDeploymentConfigurations = Action("ListDeploymentConfigurations")
ListDeviceUpdates = Action("ListDeviceUpdates")
ListDevices = Action("ListDevices")
ListModels = Action("ListModels")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApp = Action("UpdateApp")
UpdateAppConfiguration = Action("UpdateAppConfiguration")
UpdateDataSource = Action("UpdateDataSource")
UpdateDevice = Action("UpdateDevice")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Global Accelerator"
prefix = "globalaccelerator"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddCustomRoutingEndpoints = Action("AddCustomRoutingEndpoints")
AdvertiseByoipCidr = Action("AdvertiseByoipCidr")
AllowCustomRoutingTraffic = Action("AllowCustomRoutingTraffic")
CreateAccelerator = Action("CreateAccelerator")
CreateCustomRoutingAccelerator = Action("CreateCustomRoutingAccelerator")
CreateCustomRoutingEndpointGroup = Action("CreateCustomRoutingEndpointGroup")
CreateCustomRoutingListener = Action("CreateCustomRoutingListener")
CreateEndpointGroup = Action("CreateEndpointGroup")
CreateListener = Action("CreateListener")
DeleteAccelerator = Action("DeleteAccelerator")
DeleteCustomRoutingAccelerator = Action("DeleteCustomRoutingAccelerator")
DeleteCustomRoutingEndpointGroup = Action("DeleteCustomRoutingEndpointGroup")
DeleteCustomRoutingListener = Action("DeleteCustomRoutingListener")
DeleteEndpointGroup = Action("DeleteEndpointGroup")
DeleteListener = Action("DeleteListener")
DenyCustomRoutingTraffic = Action("DenyCustomRoutingTraffic")
DeprovisionByoipCidr = Action("DeprovisionByoipCidr")
DescribeAccelerator = Action("DescribeAccelerator")
DescribeAcceleratorAttributes = Action("DescribeAcceleratorAttributes")
DescribeCustomRoutingAccelerator = Action("DescribeCustomRoutingAccelerator")
DescribeCustomRoutingAcceleratorAttributes = Action(
    "DescribeCustomRoutingAcceleratorAttributes"
)
DescribeCustomRoutingEndpointGroup = Action("DescribeCustomRoutingEndpointGroup")
DescribeCustomRoutingListener = Action("DescribeCustomRoutingListener")
DescribeEndpointGroup = Action("DescribeEndpointGroup")
DescribeListener = Action("DescribeListener")
ListAccelerators = Action("ListAccelerators")
ListByoipCidrs = Action("ListByoipCidrs")
ListCustomRoutingAccelerators = Action("ListCustomRoutingAccelerators")
ListCustomRoutingEndpointGroups = Action("ListCustomRoutingEndpointGroups")
ListCustomRoutingListeners = Action("ListCustomRoutingListeners")
ListCustomRoutingPortMappings = Action("ListCustomRoutingPortMappings")
ListCustomRoutingPortMappingsByDestination = Action(
    "ListCustomRoutingPortMappingsByDestination"
)
ListEndpointGroups = Action("ListEndpointGroups")
ListListeners = Action("ListListeners")
ListTagsForResource = Action("ListTagsForResource")
ProvisionByoipCidr = Action("ProvisionByoipCidr")
RemoveCustomRoutingEndpoints = Action("RemoveCustomRoutingEndpoints")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAccelerator = Action("UpdateAccelerator")
UpdateAcceleratorAttributes = Action("UpdateAcceleratorAttributes")
UpdateCustomRoutingAccelerator = Action("UpdateCustomRoutingAccelerator")
UpdateCustomRoutingAcceleratorAttributes = Action(
    "UpdateCustomRoutingAcceleratorAttributes"
)
UpdateCustomRoutingListener = Action("UpdateCustomRoutingListener")
UpdateEndpointGroup = Action("UpdateEndpointGroup")
UpdateListener = Action("UpdateListener")
WithdrawByoipCidr = Action("WithdrawByoipCidr")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Athena"
prefix = "athena"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGetNamedQuery = Action("BatchGetNamedQuery")
BatchGetQueryExecution = Action("BatchGetQueryExecution")
CancelQueryExecution = Action("CancelQueryExecution")
CreateDataCatalog = Action("CreateDataCatalog")
CreateNamedQuery = Action("CreateNamedQuery")
CreatePreparedStatement = Action("CreatePreparedStatement")
CreateWorkGroup = Action("CreateWorkGroup")
DeleteDataCatalog = Action("DeleteDataCatalog")
DeleteNamedQuery = Action("DeleteNamedQuery")
DeletePreparedStatement = Action("DeletePreparedStatement")
DeleteWorkGroup = Action("DeleteWorkGroup")
GetCatalogs = Action("GetCatalogs")
GetDataCatalog = Action("GetDataCatalog")
GetDatabase = Action("GetDatabase")
GetExecutionEngine = Action("GetExecutionEngine")
GetExecutionEngines = Action("GetExecutionEngines")
GetNamedQuery = Action("GetNamedQuery")
GetNamespace = Action("GetNamespace")
GetNamespaces = Action("GetNamespaces")
GetPreparedStatement = Action("GetPreparedStatement")
GetQueryExecution = Action("GetQueryExecution")
GetQueryExecutions = Action("GetQueryExecutions")
GetQueryResults = Action("GetQueryResults")
GetQueryResultsStream = Action("GetQueryResultsStream")
GetTable = Action("GetTable")
GetTableMetadata = Action("GetTableMetadata")
GetTables = Action("GetTables")
GetWorkGroup = Action("GetWorkGroup")
ListDataCatalogs = Action("ListDataCatalogs")
ListDatabases = Action("ListDatabases")
ListEngineVersions = Action("ListEngineVersions")
ListNamedQueries = Action("ListNamedQueries")
ListPreparedStatements = Action("ListPreparedStatements")
ListQueryExecutions = Action("ListQueryExecutions")
ListTableMetadata = Action("ListTableMetadata")
ListTagsForResource = Action("ListTagsForResource")
ListWorkGroups = Action("ListWorkGroups")
RunQuery = Action("RunQuery")
StartQueryExecution = Action("StartQueryExecution")
StopQueryExecution = Action("StopQueryExecution")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDataCatalog = Action("UpdateDataCatalog")
UpdatePreparedStatement = Action("UpdatePreparedStatement")
UpdateWorkGroup = Action("UpdateWorkGroup")



# Example taken from AWS docs:
# http://docs.aws.amazon.com/AmazonECS/latest/developerguide/instance_IAM_role.html

import awacs.ecr as aecr
import awacs.ecs as aecs
import awacs.logs as alogs
from awacs.aws import Allow, Policy, Statement

pd = Policy(
    Statement=[
        Statement(
            Effect=Allow,
            Action=[
                aecs.CreateCluster,
                aecs.DeregisterContainerInstance,
                aecs.DiscoverPollEndpoint,
                aecs.Poll,
                aecs.RegisterContainerInstance,
                aecs.StartTelemetrySession,
                aecr.GetAuthorizationToken,
                aecr.BatchCheckLayerAvailability,
                aecr.GetDownloadUrlForLayer,
                aecr.BatchGetImage,
                alogs.CreateLogStream,
                alogs.PutLogEvents,
                aecs.Action("Submit*"),
            ],
            Resource=["*"],
        )
    ]
)
print(pd.to_json())



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Managed Streaming for Kafka Connect"
prefix = "kafkaconnect"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateConnector = Action("CreateConnector")
CreateCustomPlugin = Action("CreateCustomPlugin")
CreateWorkerConfiguration = Action("CreateWorkerConfiguration")
DeleteConnector = Action("DeleteConnector")
DescribeConnector = Action("DescribeConnector")
DescribeCustomPlugin = Action("DescribeCustomPlugin")
DescribeWorkerConfiguration = Action("DescribeWorkerConfiguration")
ListConnectors = Action("ListConnectors")
ListCustomPlugins = Action("ListCustomPlugins")
ListWorkerConfigurations = Action("ListWorkerConfigurations")
UpdateConnector = Action("UpdateConnector")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Application Auto Scaling"
prefix = "application-autoscaling"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DeleteScalingPolicy = Action("DeleteScalingPolicy")
DeleteScheduledAction = Action("DeleteScheduledAction")
DeregisterScalableTarget = Action("DeregisterScalableTarget")
DescribeScalableTargets = Action("DescribeScalableTargets")
DescribeScalingActivities = Action("DescribeScalingActivities")
DescribeScalingPolicies = Action("DescribeScalingPolicies")
DescribeScheduledActions = Action("DescribeScheduledActions")
PutScalingPolicy = Action("PutScalingPolicy")
PutScheduledAction = Action("PutScheduledAction")
RegisterScalableTarget = Action("RegisterScalableTarget")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Directory Service"
prefix = "ds"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptSharedDirectory = Action("AcceptSharedDirectory")
AddIpRoutes = Action("AddIpRoutes")
AddRegion = Action("AddRegion")
AddTagsToResource = Action("AddTagsToResource")
AuthorizeApplication = Action("AuthorizeApplication")
CancelSchemaExtension = Action("CancelSchemaExtension")
CheckAlias = Action("CheckAlias")
ConnectDirectory = Action("ConnectDirectory")
CreateAlias = Action("CreateAlias")
CreateComputer = Action("CreateComputer")
CreateConditionalForwarder = Action("CreateConditionalForwarder")
CreateDirectory = Action("CreateDirectory")
CreateIdentityPoolDirectory = Action("CreateIdentityPoolDirectory")
CreateLogSubscription = Action("CreateLogSubscription")
CreateMicrosoftAD = Action("CreateMicrosoftAD")
CreateSnapshot = Action("CreateSnapshot")
CreateTrust = Action("CreateTrust")
DeleteConditionalForwarder = Action("DeleteConditionalForwarder")
DeleteDirectory = Action("DeleteDirectory")
DeleteLogSubscription = Action("DeleteLogSubscription")
DeleteSnapshot = Action("DeleteSnapshot")
DeleteTrust = Action("DeleteTrust")
DeregisterCertificate = Action("DeregisterCertificate")
DeregisterEventTopic = Action("DeregisterEventTopic")
DescribeCertificate = Action("DescribeCertificate")
DescribeConditionalForwarders = Action("DescribeConditionalForwarders")
DescribeDirectories = Action("DescribeDirectories")
DescribeDomainControllers = Action("DescribeDomainControllers")
DescribeEventTopics = Action("DescribeEventTopics")
DescribeLDAPSSettings = Action("DescribeLDAPSSettings")
DescribeRegions = Action("DescribeRegions")
DescribeSharedDirectories = Action("DescribeSharedDirectories")
DescribeSnapshots = Action("DescribeSnapshots")
DescribeTrusts = Action("DescribeTrusts")
DisableClientAuthentication = Action("DisableClientAuthentication")
DisableLDAPS = Action("DisableLDAPS")
DisableRadius = Action("DisableRadius")
DisableSso = Action("DisableSso")
EnableClientAuthentication = Action("EnableClientAuthentication")
EnableLDAPS = Action("EnableLDAPS")
EnableRadius = Action("EnableRadius")
EnableSso = Action("EnableSso")
GetAuthorizedApplicationDetails = Action("GetAuthorizedApplicationDetails")
GetDirectoryLimits = Action("GetDirectoryLimits")
GetSnapshotLimits = Action("GetSnapshotLimits")
ListAuthorizedApplications = Action("ListAuthorizedApplications")
ListCertificates = Action("ListCertificates")
ListIpRoutes = Action("ListIpRoutes")
ListLogSubscriptions = Action("ListLogSubscriptions")
ListSchemaExtensions = Action("ListSchemaExtensions")
ListTagsForResource = Action("ListTagsForResource")
RegisterCertificate = Action("RegisterCertificate")
RegisterEventTopic = Action("RegisterEventTopic")
RejectSharedDirectory = Action("RejectSharedDirectory")
RemoveIpRoutes = Action("RemoveIpRoutes")
RemoveRegion = Action("RemoveRegion")
RemoveTagsFromResource = Action("RemoveTagsFromResource")
ResetUserPassword = Action("ResetUserPassword")
RestoreFromSnapshot = Action("RestoreFromSnapshot")
ShareDirectory = Action("ShareDirectory")
StartSchemaExtension = Action("StartSchemaExtension")
UnauthorizeApplication = Action("UnauthorizeApplication")
UnshareDirectory = Action("UnshareDirectory")
UpdateConditionalForwarder = Action("UpdateConditionalForwarder")
UpdateNumberOfDomainControllers = Action("UpdateNumberOfDomainControllers")
UpdateRadius = Action("UpdateRadius")
UpdateTrust = Action("UpdateTrust")
VerifyTrust = Action("VerifyTrust")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CloudWatch Logs"
prefix = "logs"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateKmsKey = Action("AssociateKmsKey")
CancelExportTask = Action("CancelExportTask")
CreateExportTask = Action("CreateExportTask")
CreateLogDelivery = Action("CreateLogDelivery")
CreateLogGroup = Action("CreateLogGroup")
CreateLogStream = Action("CreateLogStream")
DeleteDestination = Action("DeleteDestination")
DeleteLogDelivery = Action("DeleteLogDelivery")
DeleteLogGroup = Action("DeleteLogGroup")
DeleteLogStream = Action("DeleteLogStream")
DeleteMetricFilter = Action("DeleteMetricFilter")
DeleteQueryDefinition = Action("DeleteQueryDefinition")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteRetentionPolicy = Action("DeleteRetentionPolicy")
DeleteSubscriptionFilter = Action("DeleteSubscriptionFilter")
DescribeDestinations = Action("DescribeDestinations")
DescribeExportTasks = Action("DescribeExportTasks")
DescribeLogGroups = Action("DescribeLogGroups")
DescribeLogStreams = Action("DescribeLogStreams")
DescribeMetricFilters = Action("DescribeMetricFilters")
DescribeQueries = Action("DescribeQueries")
DescribeQueryDefinitions = Action("DescribeQueryDefinitions")
DescribeResourcePolicies = Action("DescribeResourcePolicies")
DescribeSubscriptionFilters = Action("DescribeSubscriptionFilters")
DisassociateKmsKey = Action("DisassociateKmsKey")
FilterLogEvents = Action("FilterLogEvents")
GetLogDelivery = Action("GetLogDelivery")
GetLogEvents = Action("GetLogEvents")
GetLogGroupFields = Action("GetLogGroupFields")
GetLogRecord = Action("GetLogRecord")
GetQueryResults = Action("GetQueryResults")
ListLogDeliveries = Action("ListLogDeliveries")
ListTagsLogGroup = Action("ListTagsLogGroup")
PutDestination = Action("PutDestination")
PutDestinationPolicy = Action("PutDestinationPolicy")
PutLogEvents = Action("PutLogEvents")
PutMetricFilter = Action("PutMetricFilter")
PutQueryDefinition = Action("PutQueryDefinition")
PutResourcePolicy = Action("PutResourcePolicy")
PutRetentionPolicy = Action("PutRetentionPolicy")
PutSubscriptionFilter = Action("PutSubscriptionFilter")
StartQuery = Action("StartQuery")
StopQuery = Action("StopQuery")
TagLogGroup = Action("TagLogGroup")
TestMetricFilter = Action("TestMetricFilter")
UntagLogGroup = Action("UntagLogGroup")
UpdateLogDelivery = Action("UpdateLogDelivery")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Direct Connect"
prefix = "directconnect"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptDirectConnectGatewayAssociationProposal = Action(
    "AcceptDirectConnectGatewayAssociationProposal"
)
AllocateConnectionOnInterconnect = Action("AllocateConnectionOnInterconnect")
AllocateHostedConnection = Action("AllocateHostedConnection")
AllocatePrivateVirtualInterface = Action("AllocatePrivateVirtualInterface")
AllocatePublicVirtualInterface = Action("AllocatePublicVirtualInterface")
AllocateTransitVirtualInterface = Action("AllocateTransitVirtualInterface")
AssociateConnectionWithLag = Action("AssociateConnectionWithLag")
AssociateHostedConnection = Action("AssociateHostedConnection")
AssociateMacSecKey = Action("AssociateMacSecKey")
AssociateVirtualInterface = Action("AssociateVirtualInterface")
ConfirmConnection = Action("ConfirmConnection")
ConfirmPrivateVirtualInterface = Action("ConfirmPrivateVirtualInterface")
ConfirmPublicVirtualInterface = Action("ConfirmPublicVirtualInterface")
ConfirmTransitVirtualInterface = Action("ConfirmTransitVirtualInterface")
CreateBGPPeer = Action("CreateBGPPeer")
CreateConnection = Action("CreateConnection")
CreateDirectConnectGateway = Action("CreateDirectConnectGateway")
CreateDirectConnectGatewayAssociation = Action("CreateDirectConnectGatewayAssociation")
CreateDirectConnectGatewayAssociationProposal = Action(
    "CreateDirectConnectGatewayAssociationProposal"
)
CreateInterconnect = Action("CreateInterconnect")
CreateLag = Action("CreateLag")
CreatePrivateVirtualInterface = Action("CreatePrivateVirtualInterface")
CreatePublicVirtualInterface = Action("CreatePublicVirtualInterface")
CreateTransitVirtualInterface = Action("CreateTransitVirtualInterface")
DeleteBGPPeer = Action("DeleteBGPPeer")
DeleteConnection = Action("DeleteConnection")
DeleteDirectConnectGateway = Action("DeleteDirectConnectGateway")
DeleteDirectConnectGatewayAssociation = Action("DeleteDirectConnectGatewayAssociation")
DeleteDirectConnectGatewayAssociationProposal = Action(
    "DeleteDirectConnectGatewayAssociationProposal"
)
DeleteInterconnect = Action("DeleteInterconnect")
DeleteLag = Action("DeleteLag")
DeleteVirtualInterface = Action("DeleteVirtualInterface")
DescribeConnectionLoa = Action("DescribeConnectionLoa")
DescribeConnections = Action("DescribeConnections")
DescribeConnectionsOnInterconnect = Action("DescribeConnectionsOnInterconnect")
DescribeDirectConnectGatewayAssociationProposals = Action(
    "DescribeDirectConnectGatewayAssociationProposals"
)
DescribeDirectConnectGatewayAssociations = Action(
    "DescribeDirectConnectGatewayAssociations"
)
DescribeDirectConnectGatewayAttachments = Action(
    "DescribeDirectConnectGatewayAttachments"
)
DescribeDirectConnectGateways = Action("DescribeDirectConnectGateways")
DescribeHostedConnections = Action("DescribeHostedConnections")
DescribeInterconnectLoa = Action("DescribeInterconnectLoa")
DescribeInterconnects = Action("DescribeInterconnects")
DescribeLags = Action("DescribeLags")
DescribeLoa = Action("DescribeLoa")
DescribeLocations = Action("DescribeLocations")
DescribeTags = Action("DescribeTags")
DescribeVirtualGateways = Action("DescribeVirtualGateways")
DescribeVirtualInterfaces = Action("DescribeVirtualInterfaces")
DisassociateConnectionFromLag = Action("DisassociateConnectionFromLag")
DisassociateMacSecKey = Action("DisassociateMacSecKey")
ListVirtualInterfaceTestHistory = Action("ListVirtualInterfaceTestHistory")
StartBgpFailoverTest = Action("StartBgpFailoverTest")
StopBgpFailoverTest = Action("StopBgpFailoverTest")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConnection = Action("UpdateConnection")
UpdateDirectConnectGatewayAssociation = Action("UpdateDirectConnectGatewayAssociation")
UpdateLag = Action("UpdateLag")
UpdateVirtualInterfaceAttributes = Action("UpdateVirtualInterfaceAttributes")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon WorkMail"
prefix = "workmail"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddMembersToGroup = Action("AddMembersToGroup")
AssociateDelegateToResource = Action("AssociateDelegateToResource")
AssociateMemberToGroup = Action("AssociateMemberToGroup")
CancelMailboxExportJob = Action("CancelMailboxExportJob")
CreateAlias = Action("CreateAlias")
CreateGroup = Action("CreateGroup")
CreateInboundMailFlowRule = Action("CreateInboundMailFlowRule")
CreateMailDomain = Action("CreateMailDomain")
CreateMailUser = Action("CreateMailUser")
CreateMobileDeviceAccessRule = Action("CreateMobileDeviceAccessRule")
CreateOrganization = Action("CreateOrganization")
CreateOutboundMailFlowRule = Action("CreateOutboundMailFlowRule")
CreateResource = Action("CreateResource")
CreateSmtpGateway = Action("CreateSmtpGateway")
CreateUser = Action("CreateUser")
DeleteAccessControlRule = Action("DeleteAccessControlRule")
DeleteAlias = Action("DeleteAlias")
DeleteGroup = Action("DeleteGroup")
DeleteInboundMailFlowRule = Action("DeleteInboundMailFlowRule")
DeleteMailDomain = Action("DeleteMailDomain")
DeleteMailboxPermissions = Action("DeleteMailboxPermissions")
DeleteMobileDevice = Action("DeleteMobileDevice")
DeleteMobileDeviceAccessRule = Action("DeleteMobileDeviceAccessRule")
DeleteOrganization = Action("DeleteOrganization")
DeleteOutboundMailFlowRule = Action("DeleteOutboundMailFlowRule")
DeleteResource = Action("DeleteResource")
DeleteRetentionPolicy = Action("DeleteRetentionPolicy")
DeleteSmtpGateway = Action("DeleteSmtpGateway")
DeleteUser = Action("DeleteUser")
DeregisterFromWorkMail = Action("DeregisterFromWorkMail")
DescribeDirectories = Action("DescribeDirectories")
DescribeGroup = Action("DescribeGroup")
DescribeInboundDmarcSettings = Action("DescribeInboundDmarcSettings")
DescribeInboundMailFlowRule = Action("DescribeInboundMailFlowRule")
DescribeKmsKeys = Action("DescribeKmsKeys")
DescribeMailDomains = Action("DescribeMailDomains")
DescribeMailGroups = Action("DescribeMailGroups")
DescribeMailUsers = Action("DescribeMailUsers")
DescribeMailboxExportJob = Action("DescribeMailboxExportJob")
DescribeOrganization = Action("DescribeOrganization")
DescribeOrganizations = Action("DescribeOrganizations")
DescribeOutboundMailFlowRule = Action("DescribeOutboundMailFlowRule")
DescribeResource = Action("DescribeResource")
DescribeSmtpGateway = Action("DescribeSmtpGateway")
DescribeUser = Action("DescribeUser")
DisableMailGroups = Action("DisableMailGroups")
DisableMailUsers = Action("DisableMailUsers")
DisassociateDelegateFromResource = Action("DisassociateDelegateFromResource")
DisassociateMemberFromGroup = Action("DisassociateMemberFromGroup")
EnableMailDomain = Action("EnableMailDomain")
EnableMailGroups = Action("EnableMailGroups")
EnableMailUsers = Action("EnableMailUsers")
GetAccessControlEffect = Action("GetAccessControlEffect")
GetDefaultRetentionPolicy = Action("GetDefaultRetentionPolicy")
GetJournalingRules = Action("GetJournalingRules")
GetMailDomainDetails = Action("GetMailDomainDetails")
GetMailGroupDetails = Action("GetMailGroupDetails")
GetMailUserDetails = Action("GetMailUserDetails")
GetMailboxDetails = Action("GetMailboxDetails")
GetMobileDeviceAccessEffect = Action("GetMobileDeviceAccessEffect")
GetMobileDeviceDetails = Action("GetMobileDeviceDetails")
GetMobileDevicesForUser = Action("GetMobileDevicesForUser")
GetMobilePolicyDetails = Action("GetMobilePolicyDetails")
ListAccessControlRules = Action("ListAccessControlRules")
ListAliases = Action("ListAliases")
ListGroupMembers = Action("ListGroupMembers")
ListGroups = Action("ListGroups")
ListInboundMailFlowRules = Action("ListInboundMailFlowRules")
ListMailboxExportJobs = Action("ListMailboxExportJobs")
ListMailboxPermissions = Action("ListMailboxPermissions")
ListMembersInMailGroup = Action("ListMembersInMailGroup")
ListMobileDeviceAccessRules = Action("ListMobileDeviceAccessRules")
ListOrganizations = Action("ListOrganizations")
ListOutboundMailFlowRules = Action("ListOutboundMailFlowRules")
ListResourceDelegates = Action("ListResourceDelegates")
ListResources = Action("ListResources")
ListSmtpGateways = Action("ListSmtpGateways")
ListTagsForResource = Action("ListTagsForResource")
ListUsers = Action("ListUsers")
PutAccessControlRule = Action("PutAccessControlRule")
PutInboundDmarcSettings = Action("PutInboundDmarcSettings")
PutMailboxPermissions = Action("PutMailboxPermissions")
PutRetentionPolicy = Action("PutRetentionPolicy")
RegisterToWorkMail = Action("RegisterToWorkMail")
RemoveMembersFromGroup = Action("RemoveMembersFromGroup")
ResetPassword = Action("ResetPassword")
ResetUserPassword = Action("ResetUserPassword")
SearchMembers = Action("SearchMembers")
SetAdmin = Action("SetAdmin")
SetDefaultMailDomain = Action("SetDefaultMailDomain")
SetJournalingRules = Action("SetJournalingRules")
SetMailGroupDetails = Action("SetMailGroupDetails")
SetMailUserDetails = Action("SetMailUserDetails")
SetMobilePolicyDetails = Action("SetMobilePolicyDetails")
StartMailboxExportJob = Action("StartMailboxExportJob")
TagResource = Action("TagResource")
TestInboundMailFlowRules = Action("TestInboundMailFlowRules")
TestOutboundMailFlowRules = Action("TestOutboundMailFlowRules")
UntagResource = Action("UntagResource")
UpdateInboundMailFlowRule = Action("UpdateInboundMailFlowRule")
UpdateMailboxQuota = Action("UpdateMailboxQuota")
UpdateMobileDeviceAccessRule = Action("UpdateMobileDeviceAccessRule")
UpdateOutboundMailFlowRule = Action("UpdateOutboundMailFlowRule")
UpdatePrimaryEmailAddress = Action("UpdatePrimaryEmailAddress")
UpdateResource = Action("UpdateResource")
UpdateSmtpGateway = Action("UpdateSmtpGateway")
WipeMobileDevice = Action("WipeMobileDevice")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT 1-Click"
prefix = "iot1click"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateDeviceWithPlacement = Action("AssociateDeviceWithPlacement")
ClaimDevicesByClaimCode = Action("ClaimDevicesByClaimCode")
CreatePlacement = Action("CreatePlacement")
CreateProject = Action("CreateProject")
DeletePlacement = Action("DeletePlacement")
DeleteProject = Action("DeleteProject")
DescribeDevice = Action("DescribeDevice")
DescribePlacement = Action("DescribePlacement")
DescribeProject = Action("DescribeProject")
DisassociateDeviceFromPlacement = Action("DisassociateDeviceFromPlacement")
FinalizeDeviceClaim = Action("FinalizeDeviceClaim")
GetDeviceMethods = Action("GetDeviceMethods")
GetDevicesInPlacement = Action("GetDevicesInPlacement")
InitializeDeviceClaim = Action("InitializeDeviceClaim")
InitiateDeviceClaim = Action("InitiateDeviceClaim")
InvokeDeviceMethod = Action("InvokeDeviceMethod")
ListDeviceEvents = Action("ListDeviceEvents")
ListDevices = Action("ListDevices")
ListPlacements = Action("ListPlacements")
ListProjects = Action("ListProjects")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UnclaimDevice = Action("UnclaimDevice")
UntagResource = Action("UntagResource")
UpdateDeviceState = Action("UpdateDeviceState")
UpdatePlacement = Action("UpdatePlacement")
UpdateProject = Action("UpdateProject")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Proton"
prefix = "proton"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptEnvironmentAccountConnection = Action("AcceptEnvironmentAccountConnection")
CancelEnvironmentDeployment = Action("CancelEnvironmentDeployment")
CancelServiceInstanceDeployment = Action("CancelServiceInstanceDeployment")
CancelServicePipelineDeployment = Action("CancelServicePipelineDeployment")
CreateEnvironment = Action("CreateEnvironment")
CreateEnvironmentAccountConnection = Action("CreateEnvironmentAccountConnection")
CreateEnvironmentTemplate = Action("CreateEnvironmentTemplate")
CreateEnvironmentTemplateMajorVersion = Action("CreateEnvironmentTemplateMajorVersion")
CreateEnvironmentTemplateMinorVersion = Action("CreateEnvironmentTemplateMinorVersion")
CreateEnvironmentTemplateVersion = Action("CreateEnvironmentTemplateVersion")
CreateService = Action("CreateService")
CreateServiceTemplate = Action("CreateServiceTemplate")
CreateServiceTemplateMajorVersion = Action("CreateServiceTemplateMajorVersion")
CreateServiceTemplateMinorVersion = Action("CreateServiceTemplateMinorVersion")
CreateServiceTemplateVersion = Action("CreateServiceTemplateVersion")
DeleteAccountRoles = Action("DeleteAccountRoles")
DeleteEnvironment = Action("DeleteEnvironment")
DeleteEnvironmentAccountConnection = Action("DeleteEnvironmentAccountConnection")
DeleteEnvironmentTemplate = Action("DeleteEnvironmentTemplate")
DeleteEnvironmentTemplateMajorVersion = Action("DeleteEnvironmentTemplateMajorVersion")
DeleteEnvironmentTemplateMinorVersion = Action("DeleteEnvironmentTemplateMinorVersion")
DeleteEnvironmentTemplateVersion = Action("DeleteEnvironmentTemplateVersion")
DeleteService = Action("DeleteService")
DeleteServiceTemplate = Action("DeleteServiceTemplate")
DeleteServiceTemplateMajorVersion = Action("DeleteServiceTemplateMajorVersion")
DeleteServiceTemplateMinorVersion = Action("DeleteServiceTemplateMinorVersion")
DeleteServiceTemplateVersion = Action("DeleteServiceTemplateVersion")
GetAccountRoles = Action("GetAccountRoles")
GetAccountSettings = Action("GetAccountSettings")
GetEnvironment = Action("GetEnvironment")
GetEnvironmentAccountConnection = Action("GetEnvironmentAccountConnection")
GetEnvironmentTemplate = Action("GetEnvironmentTemplate")
GetEnvironmentTemplateMajorVersion = Action("GetEnvironmentTemplateMajorVersion")
GetEnvironmentTemplateMinorVersion = Action("GetEnvironmentTemplateMinorVersion")
GetEnvironmentTemplateVersion = Action("GetEnvironmentTemplateVersion")
GetService = Action("GetService")
GetServiceInstance = Action("GetServiceInstance")
GetServiceTemplate = Action("GetServiceTemplate")
GetServiceTemplateMajorVersion = Action("GetServiceTemplateMajorVersion")
GetServiceTemplateMinorVersion = Action("GetServiceTemplateMinorVersion")
GetServiceTemplateVersion = Action("GetServiceTemplateVersion")
ListEnvironmentAccountConnections = Action("ListEnvironmentAccountConnections")
ListEnvironmentTemplateMajorVersions = Action("ListEnvironmentTemplateMajorVersions")
ListEnvironmentTemplateMinorVersions = Action("ListEnvironmentTemplateMinorVersions")
ListEnvironmentTemplateVersions = Action("ListEnvironmentTemplateVersions")
ListEnvironmentTemplates = Action("ListEnvironmentTemplates")
ListEnvironments = Action("ListEnvironments")
ListServiceInstances = Action("ListServiceInstances")
ListServiceTemplateMajorVersions = Action("ListServiceTemplateMajorVersions")
ListServiceTemplateMinorVersions = Action("ListServiceTemplateMinorVersions")
ListServiceTemplateVersions = Action("ListServiceTemplateVersions")
ListServiceTemplates = Action("ListServiceTemplates")
ListServices = Action("ListServices")
ListTagsForResource = Action("ListTagsForResource")
RejectEnvironmentAccountConnection = Action("RejectEnvironmentAccountConnection")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAccountRoles = Action("UpdateAccountRoles")
UpdateAccountSettings = Action("UpdateAccountSettings")
UpdateEnvironment = Action("UpdateEnvironment")
UpdateEnvironmentAccountConnection = Action("UpdateEnvironmentAccountConnection")
UpdateEnvironmentTemplate = Action("UpdateEnvironmentTemplate")
UpdateEnvironmentTemplateMajorVersion = Action("UpdateEnvironmentTemplateMajorVersion")
UpdateEnvironmentTemplateMinorVersion = Action("UpdateEnvironmentTemplateMinorVersion")
UpdateEnvironmentTemplateVersion = Action("UpdateEnvironmentTemplateVersion")
UpdateService = Action("UpdateService")
UpdateServiceInstance = Action("UpdateServiceInstance")
UpdateServicePipeline = Action("UpdateServicePipeline")
UpdateServiceTemplate = Action("UpdateServiceTemplate")
UpdateServiceTemplateMajorVersion = Action("UpdateServiceTemplateMajorVersion")
UpdateServiceTemplateMinorVersion = Action("UpdateServiceTemplateMinorVersion")
UpdateServiceTemplateVersion = Action("UpdateServiceTemplateVersion")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS App Mesh"
prefix = "appmesh"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateGatewayRoute = Action("CreateGatewayRoute")
CreateMesh = Action("CreateMesh")
CreateRoute = Action("CreateRoute")
CreateVirtualGateway = Action("CreateVirtualGateway")
CreateVirtualNode = Action("CreateVirtualNode")
CreateVirtualRouter = Action("CreateVirtualRouter")
CreateVirtualService = Action("CreateVirtualService")
DeleteGatewayRoute = Action("DeleteGatewayRoute")
DeleteMesh = Action("DeleteMesh")
DeleteRoute = Action("DeleteRoute")
DeleteVirtualGateway = Action("DeleteVirtualGateway")
DeleteVirtualNode = Action("DeleteVirtualNode")
DeleteVirtualRouter = Action("DeleteVirtualRouter")
DeleteVirtualService = Action("DeleteVirtualService")
DescribeGatewayRoute = Action("DescribeGatewayRoute")
DescribeMesh = Action("DescribeMesh")
DescribeRoute = Action("DescribeRoute")
DescribeVirtualGateway = Action("DescribeVirtualGateway")
DescribeVirtualNode = Action("DescribeVirtualNode")
DescribeVirtualRouter = Action("DescribeVirtualRouter")
DescribeVirtualService = Action("DescribeVirtualService")
ListGatewayRoutes = Action("ListGatewayRoutes")
ListMeshes = Action("ListMeshes")
ListRoutes = Action("ListRoutes")
ListTagsForResource = Action("ListTagsForResource")
ListVirtualGateways = Action("ListVirtualGateways")
ListVirtualNodes = Action("ListVirtualNodes")
ListVirtualRouters = Action("ListVirtualRouters")
ListVirtualServices = Action("ListVirtualServices")
StreamAggregatedResources = Action("StreamAggregatedResources")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateGatewayRoute = Action("UpdateGatewayRoute")
UpdateMesh = Action("UpdateMesh")
UpdateRoute = Action("UpdateRoute")
UpdateVirtualGateway = Action("UpdateVirtualGateway")
UpdateVirtualNode = Action("UpdateVirtualNode")
UpdateVirtualRouter = Action("UpdateVirtualRouter")
UpdateVirtualService = Action("UpdateVirtualService")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Route 53 Recovery Readiness"
prefix = "route53-recovery-readiness"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCell = Action("CreateCell")
CreateCrossAccountAuthorization = Action("CreateCrossAccountAuthorization")
CreateReadinessCheck = Action("CreateReadinessCheck")
CreateRecoveryGroup = Action("CreateRecoveryGroup")
CreateResourceSet = Action("CreateResourceSet")
DeleteCell = Action("DeleteCell")
DeleteCrossAccountAuthorization = Action("DeleteCrossAccountAuthorization")
DeleteReadinessCheck = Action("DeleteReadinessCheck")
DeleteRecoveryGroup = Action("DeleteRecoveryGroup")
DeleteResourceSet = Action("DeleteResourceSet")
GetArchitectureRecommendations = Action("GetArchitectureRecommendations")
GetCell = Action("GetCell")
GetCellReadinessSummary = Action("GetCellReadinessSummary")
GetReadinessCheck = Action("GetReadinessCheck")
GetReadinessCheckResourceStatus = Action("GetReadinessCheckResourceStatus")
GetReadinessCheckStatus = Action("GetReadinessCheckStatus")
GetRecoveryGroup = Action("GetRecoveryGroup")
GetRecoveryGroupReadinessSummary = Action("GetRecoveryGroupReadinessSummary")
GetResourceSet = Action("GetResourceSet")
ListCells = Action("ListCells")
ListCrossAccountAuthorizations = Action("ListCrossAccountAuthorizations")
ListReadinessChecks = Action("ListReadinessChecks")
ListRecoveryGroups = Action("ListRecoveryGroups")
ListResourceSets = Action("ListResourceSets")
ListRules = Action("ListRules")
ListTagsForResources = Action("ListTagsForResources")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateCell = Action("UpdateCell")
UpdateReadinessCheck = Action("UpdateReadinessCheck")
UpdateRecoveryGroup = Action("UpdateRecoveryGroup")
UpdateResourceSet = Action("UpdateResourceSet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Resource Groups"
prefix = "resource-groups"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateGroup = Action("CreateGroup")
DeleteGroup = Action("DeleteGroup")
GetGroup = Action("GetGroup")
GetGroupConfiguration = Action("GetGroupConfiguration")
GetGroupQuery = Action("GetGroupQuery")
GetTags = Action("GetTags")
GroupResources = Action("GroupResources")
ListGroupResources = Action("ListGroupResources")
ListGroups = Action("ListGroups")
PutGroupConfiguration = Action("PutGroupConfiguration")
PutGroupPolicy = Action("PutGroupPolicy")
SearchResources = Action("SearchResources")
Tag = Action("Tag")
UngroupResources = Action("UngroupResources")
Untag = Action("Untag")
UpdateGroup = Action("UpdateGroup")
UpdateGroupQuery = Action("UpdateGroupQuery")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EventBridge"
prefix = "events"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivateEventSource = Action("ActivateEventSource")
CancelReplay = Action("CancelReplay")
CreateApiDestination = Action("CreateApiDestination")
CreateArchive = Action("CreateArchive")
CreateConnection = Action("CreateConnection")
CreateEventBus = Action("CreateEventBus")
CreatePartnerEventSource = Action("CreatePartnerEventSource")
DeactivateEventSource = Action("DeactivateEventSource")
DeauthorizeConnection = Action("DeauthorizeConnection")
DeleteApiDestination = Action("DeleteApiDestination")
DeleteArchive = Action("DeleteArchive")
DeleteConnection = Action("DeleteConnection")
DeleteEventBus = Action("DeleteEventBus")
DeletePartnerEventSource = Action("DeletePartnerEventSource")
DeleteRule = Action("DeleteRule")
DescribeApiDestination = Action("DescribeApiDestination")
DescribeArchive = Action("DescribeArchive")
DescribeConnection = Action("DescribeConnection")
DescribeEventBus = Action("DescribeEventBus")
DescribeEventSource = Action("DescribeEventSource")
DescribePartnerEventSource = Action("DescribePartnerEventSource")
DescribeReplay = Action("DescribeReplay")
DescribeRule = Action("DescribeRule")
DisableRule = Action("DisableRule")
EnableRule = Action("EnableRule")
InvokeApiDestination = Action("InvokeApiDestination")
ListApiDestinations = Action("ListApiDestinations")
ListArchives = Action("ListArchives")
ListConnections = Action("ListConnections")
ListEventBuses = Action("ListEventBuses")
ListEventSources = Action("ListEventSources")
ListPartnerEventSourceAccounts = Action("ListPartnerEventSourceAccounts")
ListPartnerEventSources = Action("ListPartnerEventSources")
ListReplays = Action("ListReplays")
ListRuleNamesByTarget = Action("ListRuleNamesByTarget")
ListRules = Action("ListRules")
ListTagsForResource = Action("ListTagsForResource")
ListTargetsByRule = Action("ListTargetsByRule")
PutEvents = Action("PutEvents")
PutPartnerEvents = Action("PutPartnerEvents")
PutPermission = Action("PutPermission")
PutRule = Action("PutRule")
PutTargets = Action("PutTargets")
RemovePermission = Action("RemovePermission")
RemoveTargets = Action("RemoveTargets")
StartReplay = Action("StartReplay")
TagResource = Action("TagResource")
TestEventPattern = Action("TestEventPattern")
UntagResource = Action("UntagResource")
UpdateApiDestination = Action("UpdateApiDestination")
UpdateArchive = Action("UpdateArchive")
UpdateConnection = Action("UpdateConnection")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Health APIs and Notifications"
prefix = "health"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DescribeAffectedAccountsForOrganization = Action(
    "DescribeAffectedAccountsForOrganization"
)
DescribeAffectedEntities = Action("DescribeAffectedEntities")
DescribeAffectedEntitiesForOrganization = Action(
    "DescribeAffectedEntitiesForOrganization"
)
DescribeEntityAggregates = Action("DescribeEntityAggregates")
DescribeEventAggregates = Action("DescribeEventAggregates")
DescribeEventDetails = Action("DescribeEventDetails")
DescribeEventDetailsForOrganization = Action("DescribeEventDetailsForOrganization")
DescribeEventTypes = Action("DescribeEventTypes")
DescribeEvents = Action("DescribeEvents")
DescribeEventsForOrganization = Action("DescribeEventsForOrganization")
DescribeHealthServiceStatusForOrganization = Action(
    "DescribeHealthServiceStatusForOrganization"
)
DisableHealthServiceAccessForOrganization = Action(
    "DisableHealthServiceAccessForOrganization"
)
EnableHealthServiceAccessForOrganization = Action(
    "EnableHealthServiceAccessForOrganization"
)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Shield"
prefix = "shield"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateDRTLogBucket = Action("AssociateDRTLogBucket")
AssociateDRTRole = Action("AssociateDRTRole")
AssociateHealthCheck = Action("AssociateHealthCheck")
AssociateProactiveEngagementDetails = Action("AssociateProactiveEngagementDetails")
CreateProtection = Action("CreateProtection")
CreateProtectionGroup = Action("CreateProtectionGroup")
CreateSubscription = Action("CreateSubscription")
DeleteProtection = Action("DeleteProtection")
DeleteProtectionGroup = Action("DeleteProtectionGroup")
DeleteSubscription = Action("DeleteSubscription")
DescribeAttack = Action("DescribeAttack")
DescribeAttackStatistics = Action("DescribeAttackStatistics")
DescribeDRTAccess = Action("DescribeDRTAccess")
DescribeEmergencyContactSettings = Action("DescribeEmergencyContactSettings")
DescribeProtection = Action("DescribeProtection")
DescribeProtectionGroup = Action("DescribeProtectionGroup")
DescribeSubscription = Action("DescribeSubscription")
DisableProactiveEngagement = Action("DisableProactiveEngagement")
DisassociateDRTLogBucket = Action("DisassociateDRTLogBucket")
DisassociateDRTRole = Action("DisassociateDRTRole")
DisassociateHealthCheck = Action("DisassociateHealthCheck")
EnableProactiveEngagement = Action("EnableProactiveEngagement")
GetSubscriptionState = Action("GetSubscriptionState")
ListAttacks = Action("ListAttacks")
ListProtectionGroups = Action("ListProtectionGroups")
ListProtections = Action("ListProtections")
ListResourcesInProtectionGroup = Action("ListResourcesInProtectionGroup")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateEmergencyContactSettings = Action("UpdateEmergencyContactSettings")
UpdateProtectionGroup = Action("UpdateProtectionGroup")
UpdateSubscription = Action("UpdateSubscription")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CloudSearch"
prefix = "cloudsearch"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTags = Action("AddTags")
BuildSuggesters = Action("BuildSuggesters")
CreateDomain = Action("CreateDomain")
DefineAnalysisScheme = Action("DefineAnalysisScheme")
DefineExpression = Action("DefineExpression")
DefineIndexField = Action("DefineIndexField")
DefineIndexFields = Action("DefineIndexFields")
DefineSuggester = Action("DefineSuggester")
DeleteAnalysisScheme = Action("DeleteAnalysisScheme")
DeleteDomain = Action("DeleteDomain")
DeleteExpression = Action("DeleteExpression")
DeleteIndexField = Action("DeleteIndexField")
DeleteSuggester = Action("DeleteSuggester")
DescribeAnalysisSchemes = Action("DescribeAnalysisSchemes")
DescribeAvailabilityOptions = Action("DescribeAvailabilityOptions")
DescribeDomainEndpointOptions = Action("DescribeDomainEndpointOptions")
DescribeDomains = Action("DescribeDomains")
DescribeExpressions = Action("DescribeExpressions")
DescribeIndexFields = Action("DescribeIndexFields")
DescribeScalingParameters = Action("DescribeScalingParameters")
DescribeServiceAccessPolicies = Action("DescribeServiceAccessPolicies")
DescribeSuggesters = Action("DescribeSuggesters")
IndexDocuments = Action("IndexDocuments")
ListDomainNames = Action("ListDomainNames")
ListTags = Action("ListTags")
RemoveTags = Action("RemoveTags")
UpdateAvailabilityOptions = Action("UpdateAvailabilityOptions")
UpdateDomainEndpointOptions = Action("UpdateDomainEndpointOptions")
UpdateScalingParameters = Action("UpdateScalingParameters")
UpdateServiceAccessPolicies = Action("UpdateServiceAccessPolicies")
document = Action("document")
search = Action("search")
suggest = Action("suggest")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Database Migration Service"
prefix = "dms"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToResource = Action("AddTagsToResource")
ApplyPendingMaintenanceAction = Action("ApplyPendingMaintenanceAction")
CancelReplicationTaskAssessmentRun = Action("CancelReplicationTaskAssessmentRun")
CreateEndpoint = Action("CreateEndpoint")
CreateEventSubscription = Action("CreateEventSubscription")
CreateReplicationInstance = Action("CreateReplicationInstance")
CreateReplicationSubnetGroup = Action("CreateReplicationSubnetGroup")
CreateReplicationTask = Action("CreateReplicationTask")
DeleteCertificate = Action("DeleteCertificate")
DeleteConnection = Action("DeleteConnection")
DeleteEndpoint = Action("DeleteEndpoint")
DeleteEventSubscription = Action("DeleteEventSubscription")
DeleteReplicationInstance = Action("DeleteReplicationInstance")
DeleteReplicationSubnetGroup = Action("DeleteReplicationSubnetGroup")
DeleteReplicationTask = Action("DeleteReplicationTask")
DeleteReplicationTaskAssessmentRun = Action("DeleteReplicationTaskAssessmentRun")
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeApplicableIndividualAssessments = Action(
    "DescribeApplicableIndividualAssessments"
)
DescribeCertificates = Action("DescribeCertificates")
DescribeConnections = Action("DescribeConnections")
DescribeEndpointSettings = Action("DescribeEndpointSettings")
DescribeEndpointTypes = Action("DescribeEndpointTypes")
DescribeEndpoints = Action("DescribeEndpoints")
DescribeEventCategories = Action("DescribeEventCategories")
DescribeEventSubscriptions = Action("DescribeEventSubscriptions")
DescribeEvents = Action("DescribeEvents")
DescribeOrderableReplicationInstances = Action("DescribeOrderableReplicationInstances")
DescribeRefreshSchemasStatus = Action("DescribeRefreshSchemasStatus")
DescribeReplicationInstanceTaskLogs = Action("DescribeReplicationInstanceTaskLogs")
DescribeReplicationInstances = Action("DescribeReplicationInstances")
DescribeReplicationSubnetGroups = Action("DescribeReplicationSubnetGroups")
DescribeReplicationTaskAssessmentResults = Action(
    "DescribeReplicationTaskAssessmentResults"
)
DescribeReplicationTaskAssessmentRuns = Action("DescribeReplicationTaskAssessmentRuns")
DescribeReplicationTaskIndividualAssessments = Action(
    "DescribeReplicationTaskIndividualAssessments"
)
DescribeReplicationTasks = Action("DescribeReplicationTasks")
DescribeSchemas = Action("DescribeSchemas")
DescribeTableStatistics = Action("DescribeTableStatistics")
ImportCertificate = Action("ImportCertificate")
ListTagsForResource = Action("ListTagsForResource")
ModifyEndpoint = Action("ModifyEndpoint")
ModifyEventSubscription = Action("ModifyEventSubscription")
ModifyReplicationInstance = Action("ModifyReplicationInstance")
ModifyReplicationSubnetGroup = Action("ModifyReplicationSubnetGroup")
ModifyReplicationTask = Action("ModifyReplicationTask")
MoveReplicationTask = Action("MoveReplicationTask")
RebootReplicationInstance = Action("RebootReplicationInstance")
RefreshSchemas = Action("RefreshSchemas")
ReloadTables = Action("ReloadTables")
RemoveTagsFromResource = Action("RemoveTagsFromResource")
StartReplicationTask = Action("StartReplicationTask")
StartReplicationTaskAssessment = Action("StartReplicationTaskAssessment")
StartReplicationTaskAssessmentRun = Action("StartReplicationTaskAssessmentRun")
StopReplicationTask = Action("StopReplicationTask")
TestConnection = Action("TestConnection")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Cost Explorer Service"
prefix = "ce"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateAnomalyMonitor = Action("CreateAnomalyMonitor")
CreateAnomalySubscription = Action("CreateAnomalySubscription")
CreateCostCategoryDefinition = Action("CreateCostCategoryDefinition")
CreateNotificationSubscription = Action("CreateNotificationSubscription")
CreateReport = Action("CreateReport")
DeleteAnomalyMonitor = Action("DeleteAnomalyMonitor")
DeleteAnomalySubscription = Action("DeleteAnomalySubscription")
DeleteCostCategoryDefinition = Action("DeleteCostCategoryDefinition")
DeleteNotificationSubscription = Action("DeleteNotificationSubscription")
DeleteReport = Action("DeleteReport")
DescribeCostCategoryDefinition = Action("DescribeCostCategoryDefinition")
DescribeNotificationSubscription = Action("DescribeNotificationSubscription")
DescribeReport = Action("DescribeReport")
GetAnomalies = Action("GetAnomalies")
GetAnomalyMonitors = Action("GetAnomalyMonitors")
GetAnomalySubscriptions = Action("GetAnomalySubscriptions")
GetCostAndUsage = Action("GetCostAndUsage")
GetCostAndUsageWithResources = Action("GetCostAndUsageWithResources")
GetCostCategories = Action("GetCostCategories")
GetCostForecast = Action("GetCostForecast")
GetDimensionValues = Action("GetDimensionValues")
GetPreferences = Action("GetPreferences")
GetReservationCoverage = Action("GetReservationCoverage")
GetReservationPurchaseRecommendation = Action("GetReservationPurchaseRecommendation")
GetReservationUtilization = Action("GetReservationUtilization")
GetRightsizingRecommendation = Action("GetRightsizingRecommendation")
GetSavingsPlansCoverage = Action("GetSavingsPlansCoverage")
GetSavingsPlansPurchaseRecommendation = Action("GetSavingsPlansPurchaseRecommendation")
GetSavingsPlansUtilization = Action("GetSavingsPlansUtilization")
GetSavingsPlansUtilizationDetails = Action("GetSavingsPlansUtilizationDetails")
GetTags = Action("GetTags")
GetUsageForecast = Action("GetUsageForecast")
ListCostCategoryDefinitions = Action("ListCostCategoryDefinitions")
ProvideAnomalyFeedback = Action("ProvideAnomalyFeedback")
UpdateAnomalyMonitor = Action("UpdateAnomalyMonitor")
UpdateAnomalySubscription = Action("UpdateAnomalySubscription")
UpdateCostCategoryDefinition = Action("UpdateCostCategoryDefinition")
UpdateNotificationSubscription = Action("UpdateNotificationSubscription")
UpdatePreferences = Action("UpdatePreferences")
UpdateReport = Action("UpdateReport")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Systems Manager"
prefix = "ssm"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToResource = Action("AddTagsToResource")
AssociateOpsItemRelatedItem = Action("AssociateOpsItemRelatedItem")
CancelCommand = Action("CancelCommand")
CancelMaintenanceWindowExecution = Action("CancelMaintenanceWindowExecution")
CreateActivation = Action("CreateActivation")
CreateAssociation = Action("CreateAssociation")
CreateAssociationBatch = Action("CreateAssociationBatch")
CreateDocument = Action("CreateDocument")
CreateMaintenanceWindow = Action("CreateMaintenanceWindow")
CreateOpsItem = Action("CreateOpsItem")
CreateOpsMetadata = Action("CreateOpsMetadata")
CreatePatchBaseline = Action("CreatePatchBaseline")
CreateResourceDataSync = Action("CreateResourceDataSync")
DeleteActivation = Action("DeleteActivation")
DeleteAssociation = Action("DeleteAssociation")
DeleteDocument = Action("DeleteDocument")
DeleteInventory = Action("DeleteInventory")
DeleteMaintenanceWindow = Action("DeleteMaintenanceWindow")
DeleteOpsMetadata = Action("DeleteOpsMetadata")
DeleteParameter = Action("DeleteParameter")
DeleteParameters = Action("DeleteParameters")
DeletePatchBaseline = Action("DeletePatchBaseline")
DeleteResourceDataSync = Action("DeleteResourceDataSync")
DeregisterManagedInstance = Action("DeregisterManagedInstance")
DeregisterPatchBaselineForPatchGroup = Action("DeregisterPatchBaselineForPatchGroup")
DeregisterTargetFromMaintenanceWindow = Action("DeregisterTargetFromMaintenanceWindow")
DeregisterTaskFromMaintenanceWindow = Action("DeregisterTaskFromMaintenanceWindow")
DescribeActivations = Action("DescribeActivations")
DescribeAssociation = Action("DescribeAssociation")
DescribeAssociationExecutionTargets = Action("DescribeAssociationExecutionTargets")
DescribeAssociationExecutions = Action("DescribeAssociationExecutions")
DescribeAutomationExecutions = Action("DescribeAutomationExecutions")
DescribeAutomationStepExecutions = Action("DescribeAutomationStepExecutions")
DescribeAvailablePatches = Action("DescribeAvailablePatches")
DescribeDocument = Action("DescribeDocument")
DescribeDocumentParameters = Action("DescribeDocumentParameters")
DescribeDocumentPermission = Action("DescribeDocumentPermission")
DescribeEffectiveInstanceAssociations = Action("DescribeEffectiveInstanceAssociations")
DescribeEffectivePatchesForPatchBaseline = Action(
    "DescribeEffectivePatchesForPatchBaseline"
)
DescribeInstanceAssociationsStatus = Action("DescribeInstanceAssociationsStatus")
DescribeInstanceInformation = Action("DescribeInstanceInformation")
DescribeInstancePatchStates = Action("DescribeInstancePatchStates")
DescribeInstancePatchStatesForPatchGroup = Action(
    "DescribeInstancePatchStatesForPatchGroup"
)
DescribeInstancePatches = Action("DescribeInstancePatches")
DescribeInstanceProperties = Action("DescribeInstanceProperties")
DescribeInventoryDeletions = Action("DescribeInventoryDeletions")
DescribeMaintenanceWindowExecutionTaskInvocations = Action(
    "DescribeMaintenanceWindowExecutionTaskInvocations"
)
DescribeMaintenanceWindowExecutionTasks = Action(
    "DescribeMaintenanceWindowExecutionTasks"
)
DescribeMaintenanceWindowExecutions = Action("DescribeMaintenanceWindowExecutions")
DescribeMaintenanceWindowSchedule = Action("DescribeMaintenanceWindowSchedule")
DescribeMaintenanceWindowTargets = Action("DescribeMaintenanceWindowTargets")
DescribeMaintenanceWindowTasks = Action("DescribeMaintenanceWindowTasks")
DescribeMaintenanceWindows = Action("DescribeMaintenanceWindows")
DescribeMaintenanceWindowsForTarget = Action("DescribeMaintenanceWindowsForTarget")
DescribeOpsItems = Action("DescribeOpsItems")
DescribeParameters = Action("DescribeParameters")
DescribePatchBaselines = Action("DescribePatchBaselines")
DescribePatchGroupState = Action("DescribePatchGroupState")
DescribePatchGroups = Action("DescribePatchGroups")
DescribePatchProperties = Action("DescribePatchProperties")
DescribeSessions = Action("DescribeSessions")
DisassociateOpsItemRelatedItem = Action("DisassociateOpsItemRelatedItem")
GetAutomationExecution = Action("GetAutomationExecution")
GetCalendarState = Action("GetCalendarState")
GetCommandInvocation = Action("GetCommandInvocation")
GetConnectionStatus = Action("GetConnectionStatus")
GetDefaultPatchBaseline = Action("GetDefaultPatchBaseline")
GetDeployablePatchSnapshotForInstance = Action("GetDeployablePatchSnapshotForInstance")
GetDocument = Action("GetDocument")
GetInventory = Action("GetInventory")
GetInventorySchema = Action("GetInventorySchema")
GetMaintenanceWindow = Action("GetMaintenanceWindow")
GetMaintenanceWindowExecution = Action("GetMaintenanceWindowExecution")
GetMaintenanceWindowExecutionTask = Action("GetMaintenanceWindowExecutionTask")
GetMaintenanceWindowExecutionTaskInvocation = Action(
    "GetMaintenanceWindowExecutionTaskInvocation"
)
GetMaintenanceWindowTask = Action("GetMaintenanceWindowTask")
GetManifest = Action("GetManifest")
GetOpsItem = Action("GetOpsItem")
GetOpsMetadata = Action("GetOpsMetadata")
GetOpsSummary = Action("GetOpsSummary")
GetParameter = Action("GetParameter")
GetParameterHistory = Action("GetParameterHistory")
GetParameters = Action("GetParameters")
GetParametersByPath = Action("GetParametersByPath")
GetPatchBaseline = Action("GetPatchBaseline")
GetPatchBaselineForPatchGroup = Action("GetPatchBaselineForPatchGroup")
GetServiceSetting = Action("GetServiceSetting")
LabelParameterVersion = Action("LabelParameterVersion")
ListAssociationVersions = Action("ListAssociationVersions")
ListAssociations = Action("ListAssociations")
ListCommandInvocations = Action("ListCommandInvocations")
ListCommands = Action("ListCommands")
ListComplianceItems = Action("ListComplianceItems")
ListComplianceSummaries = Action("ListComplianceSummaries")
ListDocumentMetadataHistory = Action("ListDocumentMetadataHistory")
ListDocumentVersions = Action("ListDocumentVersions")
ListDocuments = Action("ListDocuments")
ListInstanceAssociations = Action("ListInstanceAssociations")
ListInventoryEntries = Action("ListInventoryEntries")
ListOpsItemEvents = Action("ListOpsItemEvents")
ListOpsItemRelatedItems = Action("ListOpsItemRelatedItems")
ListOpsMetadata = Action("ListOpsMetadata")
ListResourceComplianceSummaries = Action("ListResourceComplianceSummaries")
ListResourceDataSync = Action("ListResourceDataSync")
ListTagsForResource = Action("ListTagsForResource")
ModifyDocumentPermission = Action("ModifyDocumentPermission")
PutComplianceItems = Action("PutComplianceItems")
PutConfigurePackageResult = Action("PutConfigurePackageResult")
PutInventory = Action("PutInventory")
PutParameter = Action("PutParameter")
RegisterDefaultPatchBaseline = Action("RegisterDefaultPatchBaseline")
RegisterPatchBaselineForPatchGroup = Action("RegisterPatchBaselineForPatchGroup")
RegisterTargetWithMaintenanceWindow = Action("RegisterTargetWithMaintenanceWindow")
RegisterTaskWithMaintenanceWindow = Action("RegisterTaskWithMaintenanceWindow")
RemoveTagsFromResource = Action("RemoveTagsFromResource")
ResetServiceSetting = Action("ResetServiceSetting")
ResumeSession = Action("ResumeSession")
SendAutomationSignal = Action("SendAutomationSignal")
SendCommand = Action("SendCommand")
StartAssociationsOnce = Action("StartAssociationsOnce")
StartAutomationExecution = Action("StartAutomationExecution")
StartChangeRequestExecution = Action("StartChangeRequestExecution")
StartSession = Action("StartSession")
StopAutomationExecution = Action("StopAutomationExecution")
TerminateSession = Action("TerminateSession")
UpdateAssociation = Action("UpdateAssociation")
UpdateAssociationStatus = Action("UpdateAssociationStatus")
UpdateDocument = Action("UpdateDocument")
UpdateDocumentDefaultVersion = Action("UpdateDocumentDefaultVersion")
UpdateDocumentMetadata = Action("UpdateDocumentMetadata")
UpdateInstanceAssociationStatus = Action("UpdateInstanceAssociationStatus")
UpdateInstanceInformation = Action("UpdateInstanceInformation")
UpdateMaintenanceWindow = Action("UpdateMaintenanceWindow")
UpdateMaintenanceWindowTarget = Action("UpdateMaintenanceWindowTarget")
UpdateMaintenanceWindowTask = Action("UpdateMaintenanceWindowTask")
UpdateManagedInstanceRole = Action("UpdateManagedInstanceRole")
UpdateOpsItem = Action("UpdateOpsItem")
UpdateOpsMetadata = Action("UpdateOpsMetadata")
UpdatePatchBaseline = Action("UpdatePatchBaseline")
UpdateResourceDataSync = Action("UpdateResourceDataSync")
UpdateServiceSetting = Action("UpdateServiceSetting")



import awacs.sqs as sqs
from awacs.aws import (
    Allow,
    AWSPrincipal,
    Condition,
    DateGreaterThan,
    DateLessThan,
    IpAddress,
    Policy,
    Statement,
)

region = "us-east-1"
account = "444455556666"

pd = Policy(
    Id="Queue1_Policy_UUID",
    Statement=[
        Statement(
            Sid="Queue1_SendMessage",
            Effect=Allow,
            Principal=AWSPrincipal("111122223333"),
            Action=[sqs.SendMessage],
            Resource=[
                sqs.ARN(region, account, "queue1"),
            ],
            Condition=Condition(
                [
                    DateGreaterThan("aws:CurrentTime", "2010-08-16T12:00:00Z"),
                    DateLessThan("aws:CurrentTime", "2010-08-16T15:00:00Z"),
                    IpAddress("aws:SourceIp", ["192.0.2.0/24", "203.0.113.0/24"]),
                ]
            ),
        ),
    ],
)
print(pd.to_json())



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Glacier"
prefix = "glacier"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AbortMultipartUpload = Action("AbortMultipartUpload")
AbortVaultLock = Action("AbortVaultLock")
AddTagsToVault = Action("AddTagsToVault")
CompleteMultipartUpload = Action("CompleteMultipartUpload")
CompleteVaultLock = Action("CompleteVaultLock")
CreateVault = Action("CreateVault")
DeleteArchive = Action("DeleteArchive")
DeleteVault = Action("DeleteVault")
DeleteVaultAccessPolicy = Action("DeleteVaultAccessPolicy")
DeleteVaultNotifications = Action("DeleteVaultNotifications")
DescribeJob = Action("DescribeJob")
DescribeVault = Action("DescribeVault")
GetDataRetrievalPolicy = Action("GetDataRetrievalPolicy")
GetJobOutput = Action("GetJobOutput")
GetVaultAccessPolicy = Action("GetVaultAccessPolicy")
GetVaultLock = Action("GetVaultLock")
GetVaultNotifications = Action("GetVaultNotifications")
InitiateJob = Action("InitiateJob")
InitiateMultipartUpload = Action("InitiateMultipartUpload")
InitiateVaultLock = Action("InitiateVaultLock")
ListJobs = Action("ListJobs")
ListMultipartUploads = Action("ListMultipartUploads")
ListParts = Action("ListParts")
ListProvisionedCapacity = Action("ListProvisionedCapacity")
ListTagsForVault = Action("ListTagsForVault")
ListVaults = Action("ListVaults")
PurchaseProvisionedCapacity = Action("PurchaseProvisionedCapacity")
RemoveTagsFromVault = Action("RemoveTagsFromVault")
SetDataRetrievalPolicy = Action("SetDataRetrievalPolicy")
SetVaultAccessPolicy = Action("SetVaultAccessPolicy")
SetVaultNotifications = Action("SetVaultNotifications")
UploadArchive = Action("UploadArchive")
UploadMultipartPart = Action("UploadMultipartPart")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IAM Access Analyzer"
prefix = "access-analyzer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ApplyArchiveRule = Action("ApplyArchiveRule")
CancelPolicyGeneration = Action("CancelPolicyGeneration")
CreateAccessPreview = Action("CreateAccessPreview")
CreateAnalyzer = Action("CreateAnalyzer")
CreateArchiveRule = Action("CreateArchiveRule")
DeleteAnalyzer = Action("DeleteAnalyzer")
DeleteArchiveRule = Action("DeleteArchiveRule")
GetAccessPreview = Action("GetAccessPreview")
GetAnalyzedResource = Action("GetAnalyzedResource")
GetAnalyzer = Action("GetAnalyzer")
GetArchiveRule = Action("GetArchiveRule")
GetFinding = Action("GetFinding")
GetGeneratedPolicy = Action("GetGeneratedPolicy")
ListAccessPreviewFindings = Action("ListAccessPreviewFindings")
ListAccessPreviews = Action("ListAccessPreviews")
ListAnalyzedResources = Action("ListAnalyzedResources")
ListAnalyzers = Action("ListAnalyzers")
ListArchiveRules = Action("ListArchiveRules")
ListFindings = Action("ListFindings")
ListPolicyGenerations = Action("ListPolicyGenerations")
ListTagsForResource = Action("ListTagsForResource")
StartPolicyGeneration = Action("StartPolicyGeneration")
StartResourceScan = Action("StartResourceScan")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateArchiveRule = Action("UpdateArchiveRule")
UpdateFindings = Action("UpdateFindings")
ValidatePolicy = Action("ValidatePolicy")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Trusted Advisor"
prefix = "trustedadvisor"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DescribeAccount = Action("DescribeAccount")
DescribeAccountAccess = Action("DescribeAccountAccess")
DescribeCheckItems = Action("DescribeCheckItems")
DescribeCheckRefreshStatuses = Action("DescribeCheckRefreshStatuses")
DescribeCheckSummaries = Action("DescribeCheckSummaries")
DescribeChecks = Action("DescribeChecks")
DescribeNotificationPreferences = Action("DescribeNotificationPreferences")
DescribeOrganization = Action("DescribeOrganization")
DescribeOrganizationAccounts = Action("DescribeOrganizationAccounts")
DescribeReports = Action("DescribeReports")
DescribeServiceMetadata = Action("DescribeServiceMetadata")
ExcludeCheckItems = Action("ExcludeCheckItems")
GenerateReport = Action("GenerateReport")
IncludeCheckItems = Action("IncludeCheckItems")
ListAccountsForParent = Action("ListAccountsForParent")
ListOrganizationalUnitsForParent = Action("ListOrganizationalUnitsForParent")
ListRoots = Action("ListRoots")
RefreshCheck = Action("RefreshCheck")
SetAccountAccess = Action("SetAccountAccess")
SetOrganizationAccess = Action("SetOrganizationAccess")
UpdateNotificationPreferences = Action("UpdateNotificationPreferences")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Comprehend"
prefix = "comprehend"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchDetectDominantLanguage = Action("BatchDetectDominantLanguage")
BatchDetectEntities = Action("BatchDetectEntities")
BatchDetectKeyPhrases = Action("BatchDetectKeyPhrases")
BatchDetectSentiment = Action("BatchDetectSentiment")
BatchDetectSyntax = Action("BatchDetectSyntax")
ClassifyDocument = Action("ClassifyDocument")
ContainsPiiEntities = Action("ContainsPiiEntities")
CreateDocumentClassifier = Action("CreateDocumentClassifier")
CreateEndpoint = Action("CreateEndpoint")
CreateEntityRecognizer = Action("CreateEntityRecognizer")
DeleteDocumentClassifier = Action("DeleteDocumentClassifier")
DeleteEndpoint = Action("DeleteEndpoint")
DeleteEntityRecognizer = Action("DeleteEntityRecognizer")
DescribeDocumentClassificationJob = Action("DescribeDocumentClassificationJob")
DescribeDocumentClassifier = Action("DescribeDocumentClassifier")
DescribeDominantLanguageDetectionJob = Action("DescribeDominantLanguageDetectionJob")
DescribeEndpoint = Action("DescribeEndpoint")
DescribeEntitiesDetectionJob = Action("DescribeEntitiesDetectionJob")
DescribeEntityRecognizer = Action("DescribeEntityRecognizer")
DescribeEventsDetectionJob = Action("DescribeEventsDetectionJob")
DescribeKeyPhrasesDetectionJob = Action("DescribeKeyPhrasesDetectionJob")
DescribePiiEntitiesDetectionJob = Action("DescribePiiEntitiesDetectionJob")
DescribeSentimentDetectionJob = Action("DescribeSentimentDetectionJob")
DescribeTopicsDetectionJob = Action("DescribeTopicsDetectionJob")
DetectDominantLanguage = Action("DetectDominantLanguage")
DetectEntities = Action("DetectEntities")
DetectKeyPhrases = Action("DetectKeyPhrases")
DetectPiiEntities = Action("DetectPiiEntities")
DetectSentiment = Action("DetectSentiment")
DetectSyntax = Action("DetectSyntax")
ListDocumentClassificationJobs = Action("ListDocumentClassificationJobs")
ListDocumentClassifierSummaries = Action("ListDocumentClassifierSummaries")
ListDocumentClassifiers = Action("ListDocumentClassifiers")
ListDominantLanguageDetectionJobs = Action("ListDominantLanguageDetectionJobs")
ListEndpoints = Action("ListEndpoints")
ListEntitiesDetectionJobs = Action("ListEntitiesDetectionJobs")
ListEntityRecognizerSummaries = Action("ListEntityRecognizerSummaries")
ListEntityRecognizers = Action("ListEntityRecognizers")
ListEventsDetectionJobs = Action("ListEventsDetectionJobs")
ListKeyPhrasesDetectionJobs = Action("ListKeyPhrasesDetectionJobs")
ListPiiEntitiesDetectionJobs = Action("ListPiiEntitiesDetectionJobs")
ListSentimentDetectionJobs = Action("ListSentimentDetectionJobs")
ListTagsForResource = Action("ListTagsForResource")
ListTopicsDetectionJobs = Action("ListTopicsDetectionJobs")
StartDocumentClassificationJob = Action("StartDocumentClassificationJob")
StartDominantLanguageDetectionJob = Action("StartDominantLanguageDetectionJob")
StartEntitiesDetectionJob = Action("StartEntitiesDetectionJob")
StartEventsDetectionJob = Action("StartEventsDetectionJob")
StartKeyPhrasesDetectionJob = Action("StartKeyPhrasesDetectionJob")
StartPiiEntitiesDetectionJob = Action("StartPiiEntitiesDetectionJob")
StartSentimentDetectionJob = Action("StartSentimentDetectionJob")
StartTopicsDetectionJob = Action("StartTopicsDetectionJob")
StopDominantLanguageDetectionJob = Action("StopDominantLanguageDetectionJob")
StopEntitiesDetectionJob = Action("StopEntitiesDetectionJob")
StopEventsDetectionJob = Action("StopEventsDetectionJob")
StopKeyPhrasesDetectionJob = Action("StopKeyPhrasesDetectionJob")
StopPiiEntitiesDetectionJob = Action("StopPiiEntitiesDetectionJob")
StopSentimentDetectionJob = Action("StopSentimentDetectionJob")
StopTrainingDocumentClassifier = Action("StopTrainingDocumentClassifier")
StopTrainingEntityRecognizer = Action("StopTrainingEntityRecognizer")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateEndpoint = Action("UpdateEndpoint")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS WAF"
prefix = "waf"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateByteMatchSet = Action("CreateByteMatchSet")
CreateGeoMatchSet = Action("CreateGeoMatchSet")
CreateIPSet = Action("CreateIPSet")
CreateRateBasedRule = Action("CreateRateBasedRule")
CreateRegexMatchSet = Action("CreateRegexMatchSet")
CreateRegexPatternSet = Action("CreateRegexPatternSet")
CreateRule = Action("CreateRule")
CreateRuleGroup = Action("CreateRuleGroup")
CreateSizeConstraintSet = Action("CreateSizeConstraintSet")
CreateSqlInjectionMatchSet = Action("CreateSqlInjectionMatchSet")
CreateWebACL = Action("CreateWebACL")
CreateWebACLMigrationStack = Action("CreateWebACLMigrationStack")
CreateXssMatchSet = Action("CreateXssMatchSet")
DeleteByteMatchSet = Action("DeleteByteMatchSet")
DeleteGeoMatchSet = Action("DeleteGeoMatchSet")
DeleteIPSet = Action("DeleteIPSet")
DeleteLoggingConfiguration = Action("DeleteLoggingConfiguration")
DeletePermissionPolicy = Action("DeletePermissionPolicy")
DeleteRateBasedRule = Action("DeleteRateBasedRule")
DeleteRegexMatchSet = Action("DeleteRegexMatchSet")
DeleteRegexPatternSet = Action("DeleteRegexPatternSet")
DeleteRule = Action("DeleteRule")
DeleteRuleGroup = Action("DeleteRuleGroup")
DeleteSizeConstraintSet = Action("DeleteSizeConstraintSet")
DeleteSqlInjectionMatchSet = Action("DeleteSqlInjectionMatchSet")
DeleteWebACL = Action("DeleteWebACL")
DeleteXssMatchSet = Action("DeleteXssMatchSet")
GetByteMatchSet = Action("GetByteMatchSet")
GetChangeToken = Action("GetChangeToken")
GetChangeTokenStatus = Action("GetChangeTokenStatus")
GetGeoMatchSet = Action("GetGeoMatchSet")
GetIPSet = Action("GetIPSet")
GetLoggingConfiguration = Action("GetLoggingConfiguration")
GetPermissionPolicy = Action("GetPermissionPolicy")
GetRateBasedRule = Action("GetRateBasedRule")
GetRateBasedRuleManagedKeys = Action("GetRateBasedRuleManagedKeys")
GetRegexMatchSet = Action("GetRegexMatchSet")
GetRegexPatternSet = Action("GetRegexPatternSet")
GetRule = Action("GetRule")
GetRuleGroup = Action("GetRuleGroup")
GetSampledRequests = Action("GetSampledRequests")
GetSizeConstraintSet = Action("GetSizeConstraintSet")
GetSqlInjectionMatchSet = Action("GetSqlInjectionMatchSet")
GetWebACL = Action("GetWebACL")
GetXssMatchSet = Action("GetXssMatchSet")
ListActivatedRulesInRuleGroup = Action("ListActivatedRulesInRuleGroup")
ListByteMatchSets = Action("ListByteMatchSets")
ListGeoMatchSets = Action("ListGeoMatchSets")
ListIPSets = Action("ListIPSets")
ListLoggingConfigurations = Action("ListLoggingConfigurations")
ListRateBasedRules = Action("ListRateBasedRules")
ListRegexMatchSets = Action("ListRegexMatchSets")
ListRegexPatternSets = Action("ListRegexPatternSets")
ListRuleGroups = Action("ListRuleGroups")
ListRules = Action("ListRules")
ListSizeConstraintSets = Action("ListSizeConstraintSets")
ListSqlInjectionMatchSets = Action("ListSqlInjectionMatchSets")
ListSubscribedRuleGroups = Action("ListSubscribedRuleGroups")
ListTagsForResource = Action("ListTagsForResource")
ListWebACLs = Action("ListWebACLs")
ListXssMatchSets = Action("ListXssMatchSets")
PutLoggingConfiguration = Action("PutLoggingConfiguration")
PutPermissionPolicy = Action("PutPermissionPolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateByteMatchSet = Action("UpdateByteMatchSet")
UpdateGeoMatchSet = Action("UpdateGeoMatchSet")
UpdateIPSet = Action("UpdateIPSet")
UpdateRateBasedRule = Action("UpdateRateBasedRule")
UpdateRegexMatchSet = Action("UpdateRegexMatchSet")
UpdateRegexPatternSet = Action("UpdateRegexPatternSet")
UpdateRule = Action("UpdateRule")
UpdateRuleGroup = Action("UpdateRuleGroup")
UpdateSizeConstraintSet = Action("UpdateSizeConstraintSet")
UpdateSqlInjectionMatchSet = Action("UpdateSqlInjectionMatchSet")
UpdateWebACL = Action("UpdateWebACL")
UpdateXssMatchSet = Action("UpdateXssMatchSet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Kendra"
prefix = "kendra"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchDeleteDocument = Action("BatchDeleteDocument")
BatchGetDocumentStatus = Action("BatchGetDocumentStatus")
BatchPutDocument = Action("BatchPutDocument")
ClearQuerySuggestions = Action("ClearQuerySuggestions")
CreateDataSource = Action("CreateDataSource")
CreateFaq = Action("CreateFaq")
CreateIndex = Action("CreateIndex")
CreateQuerySuggestionsBlockList = Action("CreateQuerySuggestionsBlockList")
CreateThesaurus = Action("CreateThesaurus")
DeleteDataSource = Action("DeleteDataSource")
DeleteFaq = Action("DeleteFaq")
DeleteIndex = Action("DeleteIndex")
DeletePrincipalMapping = Action("DeletePrincipalMapping")
DeleteQuerySuggestionsBlockList = Action("DeleteQuerySuggestionsBlockList")
DeleteThesaurus = Action("DeleteThesaurus")
DescribeDataSource = Action("DescribeDataSource")
DescribeFaq = Action("DescribeFaq")
DescribeIndex = Action("DescribeIndex")
DescribePrincipalMapping = Action("DescribePrincipalMapping")
DescribeQuerySuggestionsBlockList = Action("DescribeQuerySuggestionsBlockList")
DescribeQuerySuggestionsConfig = Action("DescribeQuerySuggestionsConfig")
DescribeThesaurus = Action("DescribeThesaurus")
GetQuerySuggestions = Action("GetQuerySuggestions")
ListDataSourceSyncJobs = Action("ListDataSourceSyncJobs")
ListDataSources = Action("ListDataSources")
ListFaqs = Action("ListFaqs")
ListGroupsOlderThanOrderingId = Action("ListGroupsOlderThanOrderingId")
ListIndices = Action("ListIndices")
ListQuerySuggestionsBlockLists = Action("ListQuerySuggestionsBlockLists")
ListTagsForResource = Action("ListTagsForResource")
ListThesauri = Action("ListThesauri")
PutPrincipalMapping = Action("PutPrincipalMapping")
Query = Action("Query")
StartDataSourceSyncJob = Action("StartDataSourceSyncJob")
StopDataSourceSyncJob = Action("StopDataSourceSyncJob")
SubmitFeedback = Action("SubmitFeedback")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDataSource = Action("UpdateDataSource")
UpdateIndex = Action("UpdateIndex")
UpdateQuerySuggestionsBlockList = Action("UpdateQuerySuggestionsBlockList")
UpdateQuerySuggestionsConfig = Action("UpdateQuerySuggestionsConfig")
UpdateThesaurus = Action("UpdateThesaurus")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Certificate Manager Private Certificate Authority"
prefix = "acm-pca"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCertificateAuthority = Action("CreateCertificateAuthority")
CreateCertificateAuthorityAuditReport = Action("CreateCertificateAuthorityAuditReport")
CreatePermission = Action("CreatePermission")
DeleteCertificateAuthority = Action("DeleteCertificateAuthority")
DeletePermission = Action("DeletePermission")
DeletePolicy = Action("DeletePolicy")
DescribeCertificateAuthority = Action("DescribeCertificateAuthority")
DescribeCertificateAuthorityAuditReport = Action(
    "DescribeCertificateAuthorityAuditReport"
)
GetCertificate = Action("GetCertificate")
GetCertificateAuthorityCertificate = Action("GetCertificateAuthorityCertificate")
GetCertificateAuthorityCsr = Action("GetCertificateAuthorityCsr")
GetPolicy = Action("GetPolicy")
ImportCertificateAuthorityCertificate = Action("ImportCertificateAuthorityCertificate")
IssueCertificate = Action("IssueCertificate")
ListCertificateAuthorities = Action("ListCertificateAuthorities")
ListPermissions = Action("ListPermissions")
ListTags = Action("ListTags")
PutPolicy = Action("PutPolicy")
RestoreCertificateAuthority = Action("RestoreCertificateAuthority")
RevokeCertificate = Action("RevokeCertificate")
TagCertificateAuthority = Action("TagCertificateAuthority")
UntagCertificateAuthority = Action("UntagCertificateAuthority")
UpdateCertificateAuthority = Action("UpdateCertificateAuthority")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Batch"
prefix = "batch"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelJob = Action("CancelJob")
CreateComputeEnvironment = Action("CreateComputeEnvironment")
CreateJobQueue = Action("CreateJobQueue")
DeleteComputeEnvironment = Action("DeleteComputeEnvironment")
DeleteJobQueue = Action("DeleteJobQueue")
DeregisterJobDefinition = Action("DeregisterJobDefinition")
DescribeComputeEnvironments = Action("DescribeComputeEnvironments")
DescribeJobDefinitions = Action("DescribeJobDefinitions")
DescribeJobQueues = Action("DescribeJobQueues")
DescribeJobs = Action("DescribeJobs")
ListJobs = Action("ListJobs")
ListTagsForResource = Action("ListTagsForResource")
RegisterJobDefinition = Action("RegisterJobDefinition")
SubmitJob = Action("SubmitJob")
TagResource = Action("TagResource")
TerminateJob = Action("TerminateJob")
UntagResource = Action("UntagResource")
UpdateComputeEnvironment = Action("UpdateComputeEnvironment")
UpdateJobQueue = Action("UpdateJobQueue")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Application Discovery"
prefix = "discovery"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateConfigurationItemsToApplication = Action(
    "AssociateConfigurationItemsToApplication"
)
BatchDeleteImportData = Action("BatchDeleteImportData")
CreateApplication = Action("CreateApplication")
CreateTags = Action("CreateTags")
DeleteApplications = Action("DeleteApplications")
DeleteTags = Action("DeleteTags")
DescribeAgents = Action("DescribeAgents")
DescribeConfigurations = Action("DescribeConfigurations")
DescribeContinuousExports = Action("DescribeContinuousExports")
DescribeExportConfigurations = Action("DescribeExportConfigurations")
DescribeExportTasks = Action("DescribeExportTasks")
DescribeImportTasks = Action("DescribeImportTasks")
DescribeTags = Action("DescribeTags")
DisassociateConfigurationItemsFromApplication = Action(
    "DisassociateConfigurationItemsFromApplication"
)
ExportConfigurations = Action("ExportConfigurations")
GetDiscoverySummary = Action("GetDiscoverySummary")
ListConfigurations = Action("ListConfigurations")
ListServerNeighbors = Action("ListServerNeighbors")
StartContinuousExport = Action("StartContinuousExport")
StartDataCollectionByAgentIds = Action("StartDataCollectionByAgentIds")
StartExportTask = Action("StartExportTask")
StartImportTask = Action("StartImportTask")
StopContinuousExport = Action("StopContinuousExport")
StopDataCollectionByAgentIds = Action("StopDataCollectionByAgentIds")
UpdateApplication = Action("UpdateApplication")



from typing import Any

from awacs import sts
from awacs.aws import Allow, Policy, Principal, Statement


def make_simple_assume_statement(*principals: Any) -> Statement:
    return Statement(
        Principal=Principal("Service", principals),
        Effect=Allow,
        Action=[sts.AssumeRole],
    )


def make_simple_assume_policy(*principals: Any) -> Policy:
    return Policy(
        Statement=[make_simple_assume_statement(*principals)], Version="2012-10-17"
    )


def make_service_domain_name(service: str, region: str = "") -> str:
    """Helper function for creating proper service domain names."""
    tld = ".com.cn" if region == "cn-north-1" else ".com"
    return "{}.amazonaws{}".format(service, tld)


def get_codedeploy_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the AWS CodeDeploy AssumeRole Policy."""
    service = make_service_domain_name("codedeploy", region)
    return make_simple_assume_policy(service)


def get_default_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the Default AssumeRole Policy.

    Taken from here:
        https://github.com/boto/boto/blob/develop/boto/iam/connection.py#L29
    Used to allow ec2 instances to assume the roles in their InstanceProfile.
    """
    service = make_service_domain_name("ec2", region)
    return make_simple_assume_policy(service)


def get_ecs_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the ECS AssumeRole Policy."""
    service = make_service_domain_name("ecs", region)
    return make_simple_assume_policy(service)


def get_ecs_task_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the AssumeRole Policy for ECS Tasks."""
    service = make_service_domain_name("ecs-tasks", region)
    return make_simple_assume_policy(service)


def get_lambda_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the AWS Lambda AssumeRole Policy."""
    service = make_service_domain_name("lambda", region)
    return make_simple_assume_policy(service)


def get_lambda_edge_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the AWS Lambda@Edge AssumeRole Policy."""
    return make_simple_assume_policy(
        *[
            make_service_domain_name(service, region)
            for service in ("lambda", "edgelambda")
        ]
    )


def get_application_autoscaling_assumerole_policy(region: str = "") -> Policy:
    """Helper function for building the AWS Lambda AssumeRole Policy."""
    service = make_service_domain_name("application-autoscaling", region)
    return make_simple_assume_policy(service)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Cloud Directory"
prefix = "clouddirectory"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddFacetToObject = Action("AddFacetToObject")
ApplySchema = Action("ApplySchema")
AttachObject = Action("AttachObject")
AttachPolicy = Action("AttachPolicy")
AttachToIndex = Action("AttachToIndex")
AttachTypedLink = Action("AttachTypedLink")
BatchRead = Action("BatchRead")
BatchWrite = Action("BatchWrite")
CreateDirectory = Action("CreateDirectory")
CreateFacet = Action("CreateFacet")
CreateIndex = Action("CreateIndex")
CreateObject = Action("CreateObject")
CreateSchema = Action("CreateSchema")
CreateTypedLinkFacet = Action("CreateTypedLinkFacet")
DeleteDirectory = Action("DeleteDirectory")
DeleteFacet = Action("DeleteFacet")
DeleteObject = Action("DeleteObject")
DeleteSchema = Action("DeleteSchema")
DeleteTypedLinkFacet = Action("DeleteTypedLinkFacet")
DetachFromIndex = Action("DetachFromIndex")
DetachObject = Action("DetachObject")
DetachPolicy = Action("DetachPolicy")
DetachTypedLink = Action("DetachTypedLink")
DisableDirectory = Action("DisableDirectory")
EnableDirectory = Action("EnableDirectory")
GetDirectory = Action("GetDirectory")
GetFacet = Action("GetFacet")
GetLinkAttributes = Action("GetLinkAttributes")
GetObjectAttributes = Action("GetObjectAttributes")
GetObjectInformation = Action("GetObjectInformation")
GetSchemaAsJson = Action("GetSchemaAsJson")
GetTypedLinkFacetInformation = Action("GetTypedLinkFacetInformation")
ListAppliedSchemaArns = Action("ListAppliedSchemaArns")
ListAttachedIndices = Action("ListAttachedIndices")
ListDevelopmentSchemaArns = Action("ListDevelopmentSchemaArns")
ListDirectories = Action("ListDirectories")
ListFacetAttributes = Action("ListFacetAttributes")
ListFacetNames = Action("ListFacetNames")
ListIncomingTypedLinks = Action("ListIncomingTypedLinks")
ListIndex = Action("ListIndex")
ListManagedSchemaArns = Action("ListManagedSchemaArns")
ListObjectAttributes = Action("ListObjectAttributes")
ListObjectChildren = Action("ListObjectChildren")
ListObjectParentPaths = Action("ListObjectParentPaths")
ListObjectParents = Action("ListObjectParents")
ListObjectPolicies = Action("ListObjectPolicies")
ListOutgoingTypedLinks = Action("ListOutgoingTypedLinks")
ListPolicyAttachments = Action("ListPolicyAttachments")
ListPublishedSchemaArns = Action("ListPublishedSchemaArns")
ListTagsForResource = Action("ListTagsForResource")
ListTypedLinkFacetAttributes = Action("ListTypedLinkFacetAttributes")
ListTypedLinkFacetNames = Action("ListTypedLinkFacetNames")
LookupPolicy = Action("LookupPolicy")
PublishSchema = Action("PublishSchema")
PutSchemaFromJson = Action("PutSchemaFromJson")
RemoveFacetFromObject = Action("RemoveFacetFromObject")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateFacet = Action("UpdateFacet")
UpdateLinkAttributes = Action("UpdateLinkAttributes")
UpdateObjectAttributes = Action("UpdateObjectAttributes")
UpdateSchema = Action("UpdateSchema")
UpdateTypedLinkFacet = Action("UpdateTypedLinkFacet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS X-Ray"
prefix = "xray"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGetTraces = Action("BatchGetTraces")
CreateGroup = Action("CreateGroup")
CreateSamplingRule = Action("CreateSamplingRule")
DeleteGroup = Action("DeleteGroup")
DeleteSamplingRule = Action("DeleteSamplingRule")
GetEncryptionConfig = Action("GetEncryptionConfig")
GetGroup = Action("GetGroup")
GetGroups = Action("GetGroups")
GetInsight = Action("GetInsight")
GetInsightEvents = Action("GetInsightEvents")
GetInsightImpactGraph = Action("GetInsightImpactGraph")
GetInsightSummaries = Action("GetInsightSummaries")
GetSamplingRules = Action("GetSamplingRules")
GetSamplingStatisticSummaries = Action("GetSamplingStatisticSummaries")
GetSamplingTargets = Action("GetSamplingTargets")
GetServiceGraph = Action("GetServiceGraph")
GetTimeSeriesServiceStatistics = Action("GetTimeSeriesServiceStatistics")
GetTraceGraph = Action("GetTraceGraph")
GetTraceSummaries = Action("GetTraceSummaries")
ListTagsForResource = Action("ListTagsForResource")
PutEncryptionConfig = Action("PutEncryptionConfig")
PutTelemetryRecords = Action("PutTelemetryRecords")
PutTraceSegments = Action("PutTraceSegments")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateGroup = Action("UpdateGroup")
UpdateSamplingRule = Action("UpdateSamplingRule")
